@@ -9,6 +9,7 @@ from email.mime.text import MIMEText
 from email.mime.application import MIMEApplication
 from email.mime.multipart import MIMEMultipart
 
+from croniter import croniter
 from flask.wrappers import Response
 
 import jwt
@@ -30,7 +31,10 @@ API_RETRY = int(os.getenv('API_RETRY', 3))
 
 
 def get_jwt_token():
-    jwt_token = flask.request.cookies.get('OPSRAMP_JWT_TOKEN', '')
+    try:
+        jwt_token = flask.request.cookies.get('OPSRAMP_JWT_TOKEN', '')
+    except:  # outside Flask
+        jwt_token = os.getenv('OPSRAMP_JWT_TOKEN', '')
 
     return jwt_token
 
@@ -115,7 +119,10 @@ def get_run_result(run_id):
     with Session() as session:
         run = session.query(AnalysisRun).filter_by(id=run_id).first()
 
-    return run.get_result()
+    if run:
+        return run.get_result()
+    else:
+        return {}
 
 
 def get_ses_client():
@@ -234,3 +241,22 @@ def run_scheduled_send(analysis_send, func_compute):
 
         to_emails = analysis_send.recepients
         send_email(analysis_send.subject, os.getenv('FROM_EMAIL'), to_emails, analysis_send.message, attachment)
+
+
+def check_schedule_send(func_compute):
+    app_id = os.getenv('OAP_APP_ID')
+    now = datetime.now()
+    now_hour = datetime(now.year, now.month, now.day, now.hour)
+
+    with Session() as session:
+        sends = session.query(AnalysisSend) \
+                       .filter_by(is_active=True) \
+                       .filter(AnalysisSend.schedule.is_not(None)) \
+                       .join(AnalysisSend.analysis) \
+                       .filter_by(app_id=app_id).all()
+
+    for send in sends:
+        if croniter.is_valid(send.schedule) and croniter.match(send.schedule, now_hour):
+            os.environ['OPSRAMP_JWT_TOKEN'] = send.jwt_token
+            run_scheduled_send(send, func_compute)
+            print(send.id, '='*10)
